## A1

Part A with again includes.

And code in C++:

```cpp
int main(){}
```

And in javascript:

```javascript
const a = b => 42
```

And JSON:

```json
{
  "a": [-1, null, false, true, 42, "yes"],
  "b": {
    "c": {
      "d": []
    }
  }
}
```
And a list:

- a
- list
- to
- push
- the
- insert
- down

```{.python .cb.run}
with open('a2.md') as fp:
    print(fp.read())
```
